pub struct FullBridgeConverter<T: Instance, CH1: AdvancedChannel<T>, CH2: AdvancedChannel<T>> { /* private fields */ }Expand description
Fixed-frequency full-bridge converter driver.
Implementations
Sourceimpl<T: Instance, CH1: AdvancedChannel<T>, CH2: AdvancedChannel<T>> FullBridgeConverter<T, CH1, CH2>
impl<T: Instance, CH1: AdvancedChannel<T>, CH2: AdvancedChannel<T>> FullBridgeConverter<T, CH1, CH2>
Sourcepub fn new(_ch1: &mut CH1, _ch2: &mut CH2, frequency: Hertz) -> Self
pub fn new(_ch1: &mut CH1, _ch2: &mut CH2, frequency: Hertz) -> Self
Create a new HRTIM bridge converter driver.
Sourcepub fn get_max_compare_value_master(&mut self) -> u16
pub fn get_max_compare_value_master(&mut self) -> u16
Get the maximum compare value of a duty cycle
Sourcepub fn get_max_compare_value_ch1(&mut self) -> u16
pub fn get_max_compare_value_ch1(&mut self) -> u16
Get the maximum compare value of a duty cycle
Sourcepub fn get_max_compare_value_ch2(&mut self) -> u16
pub fn get_max_compare_value_ch2(&mut self) -> u16
Get the maximum compare value of a duty cycle
Sourcepub fn set_dead_time(&mut self, value: u16)
pub fn set_dead_time(&mut self, value: u16)
Set the dead time as a proportion of the maximum compare value
Sourcepub fn set_duty(&mut self, requested_duty: u16)
pub fn set_duty(&mut self, requested_duty: u16)
The duty is the period in which the primary switch is active
Sourcepub fn enable_outputs(&mut self)
pub fn enable_outputs(&mut self)
The duty is the period in which the primary switch is active
Sourcepub fn disable_outputs(&mut self)
pub fn disable_outputs(&mut self)
The duty is the period in which the primary switch is active
Sourcepub fn set_minimum_duty(&mut self, duty: u16)
pub fn set_minimum_duty(&mut self, duty: u16)
Set minimum FET pulse width in counts